@@ -1,12 +1,21 @@
 # -*- coding: utf-8 -*-import logging
 import logging
 
-from django_rq import job
+from django.conf import settings
 
+from django_rq import job
 from webhooks.senders.base import Senderable
-from ..conf import WEBHOOK_ATTEMPTS, WEBHOOK_OWNER_FIELD
+
 from ..models import WebhookTarget
 
+# For use with custom user models, this lets you define the owner field on a model
+WEBHOOK_OWNER_FIELD = getattr(settings, "WEBHOOK_OWNER_FIELD", "username")
+
+# List the attempts as an iterable of integers.
+#   Each number represents the amount of time to be slept between attempts
+#   The first number should always be 0 so no time is wasted.
+WEBHOOK_ATTEMPTS = getattr(settings, "WEBHOOK_EVENTS", (0, 15, 30, 60))
+
 logger = logging.getLogger(__name__)
 
 
@@ -32,12 +41,12 @@ def worker(wrapped, dkwargs, hash_value=None, *args, **kwargs):
     """
 
     if "event" not in dkwargs:
-        msg = "webhooks.django.decorators.hook requires an 'event' argument."
+        msg = "djwebhooks.decorators.redis_hook requires an 'event' argument in the decorator."
         raise TypeError(msg)
     event = dkwargs['event']
 
     if "owner" not in kwargs:
-        msg = "webhooks.django.senders.orm.sender requires an 'owner' argument."
+        msg = "djwebhooks.senders.redis_callable requires an 'owner' argument in the decorated function."
         raise TypeError(msg)
     owner = kwargs['owner']
 
@@ -64,7 +73,7 @@ def worker(wrapped, dkwargs, hash_value=None, *args, **kwargs):
     return senderobj.send()
 
 
-def sender(wrapped, dkwargs, hash_value=None, *args, **kwargs):
+def redisq_callable(wrapped, dkwargs, hash_value=None, *args, **kwargs):
     logger.debug("Starting async")
     job = worker(wrapped, dkwargs, hash_value, *args, **kwargs)
     logger.debug("Ending async")
